"""Context modules for NixMCP."""

from nixmcp.contexts.nixos_context import NixOSContext
from nixmcp.contexts.home_manager_context import HomeManagerContext

__all__ = ["NixOSContext", "HomeManagerContext"]
